KOCO_COLORS = {
    "Weiß": "#f7f6f5",
    "Schwarzgrau": "#212529",
    "Grauschwarz": "#292927",
    "Dunkelgrau": "#363932",
    "Grau": "#6e6d71",
    "Hellgrau": "#dedede",
    "Blaugrau": "#97adc2",
    "Grünblau": "#5ca19f",
    "Beige": "#faeacc",
    "Gelb": "#ffe600",
    "HF_Orange": "#ff801a",
    "HF_Dunkelrot": "#a13036",
    "HF_Flieder": "#c05b88",
    "HF_Lila": "#7b4f87",
    "HF_Blaugrün": "#55ca9b",
    "HF_Hellgrün": "#b1be13",
    "HF_Hellblau": "#5b9fc0",
    "HF_Blaugrau": "#87bbcf",
    "HF_Dunkelgrau": "#171914",
}


AREA_MAPPING_COLOR_MAPPING = {
    "Ost": KOCO_COLORS.get("HF_Blaugrün"),  # Grün-Gelb
    "West": KOCO_COLORS.get("HF_Orange"),       # Orange
    "BW": KOCO_COLORS.get("HF_Hellgrün"),        # Grün
    "Bayern": KOCO_COLORS.get("HF_Hellblau"),    # Rot
    "Unknown": KOCO_COLORS.get("Blaugrau")    # Grau für unbekannte Gebiete
}
    


import matplotlib.pyplot as plt
import area_viz.plot_data.sales_areas as sales_areas
import area_viz.plot_data.generic as generic
import area_viz.plot_data.heatmap as heatmap
import area_viz.datamodel.poi as dm_poi

import area_viz.corporate_design as ci
import area_viz.area_maps as am
import pandas as pd


def top_companies_revenue(
        revenue_data: pd.DataFrame,
        max_rank: int = 100, 
        show_company_names: bool = False) -> plt.axes:
    ax = sales_areas.germany_sales_areas()
    revenue_data.sort_values(by="DATA", ascending=False, inplace=True)
    top_companies_poi = dm_poi.plz_dataframe_to_poi_list(df=revenue_data.head(max_rank), plz2coord=am.PLZ_COORDS, data_col="DATA")
    if not show_company_names:
        for poi in top_companies_poi:
            poi.name = ""
    ax = generic.add_poi_to_map(ax=ax, poi_list=top_companies_poi)
    plt.title(f"Top {max_rank} Unternehmen nach Umsatz in Deutschland")
    return ax

def top_companies_revenue_area(
        area_name: str, 
        revenue_data: pd.DataFrame,
        max_rank: int = 100, show_company_names: bool = False) -> plt.axes:
    ax = sales_areas.germany_sales_area(area_name=area_name)
    revenue_data = revenue_data.sort_values(by="DATA", ascending=False)
    top_companies_poi = dm_poi.plz_dataframe_to_poi_list(df=revenue_data.head(max_rank), plz2coord=am.PLZ_COORDS, data_col="DATA")
    if not show_company_names:
        for poi in top_companies_poi:
            poi.name = ""
    ax = generic.add_poi_to_map(ax=ax, poi_list=top_companies_poi)
    plt.title(f"Top 100 Unternehmen nach Umsatz im Vertriebsgebiet {area_name}")
    return ax


def plz2_heatmap(
        ax: plt.Axes,
        plz2_data: pd.DataFrame,
        area: str = "Deutschland",
        show_HQ: bool = True,
        show_sales_offices: bool = True,
        show_capital_cities: bool = True,
) -> plt.Axes:
    heatmap_ax = heatmap.plz2_area(
        ax=ax,
        plz2_data=plz2_data,
        area=area,
        show_HQ=show_HQ,
        show_sales_offices=show_sales_offices,
        show_capital_cities=show_capital_cities,
    )
    return heatmap_ax

def plz3_heatmap(
        ax: plt.Axes,
        plz3_data: pd.DataFrame,
        area: str = "Deutschland",
        show_HQ: bool = True,
        show_sales_offices: bool = True,
        show_capital_cities: bool = True,
) -> plt.Axes:
    heatmap_ax = heatmap.plz3_area(
        ax=ax,
        plz3_data=plz3_data,
        area=area,
        show_HQ=show_HQ,
        show_sales_offices=show_sales_offices,
        show_capital_cities=show_capital_cities,
    )
    return heatmap_ax   


def main():
    pass

if __name__ == "__main__":
    main()


import area_viz.area_maps as am
import area_viz.datamodel.poi as poi
import dataclasses as dc

@dc.dataclass
class CapitalCity:
    name: str
    plz: str
    coords: tuple[float, float]

def load_capital_cities(capital_cities_url: str)->list[poi.POI]:
    import pandas as pd
    df = pd.read_csv(capital_cities_url, sep=",", dtype={"PLZ": str})
    capital_cities = []
    for _, row in df.iterrows():
        plz = row["PLZ"]
        city = row["Hauptstadt"]
        coords = poi.fetch_poi_from_poi_list(am.PLZ_COORDS, plz)
        if coords:
            capital_cities.append(poi.POI(name=city, coordinates=coords.coordinates))
    return capital_cities

def main():
    pass

if __name__ == "__main__":
    main()


import area_viz.datamodel.poi as dm_poi
import area_viz.area_maps as am
import pandas as pd
import random

def fetch_rand_coordinates(area: str = "Deutschland") -> tuple[float, float]:
    if area == "Deutschland":
        return random.choice(am.PLZ_COORDS).coordinates
    elif area in am.AREA_MAPPING:
        plz_prefixes = am.AREA_MAPPING[area]
        filtered_coords = [coord for coord in am.PLZ_COORDS if any(coord.name.startswith(prefix) for prefix in plz_prefixes)]
        if filtered_coords:
            return random.choice(filtered_coords).coordinates
    return (0.0, 0.0)  # Default fallback coordinates

def poi_list(
        n_pois: int = 10, 
        min_value: float = 0, 
        max_value: float = 100, 
        scale_values: float = 1,
        marker: str = 'o', 
        color: str = 'blue',
        hide_annotations: bool = False,
        area: str = "Deutschland"
        ) -> list[dm_poi.POI]:
    poi_list = []
    for i in range(n_pois):
        rand_coords = fetch_rand_coordinates(area=area)
        poi = dm_poi.POI(
            name=f"POI {i+1}",
            coordinates=rand_coords,
            marker=marker,
            color=color,
            size=random.uniform(min_value, max_value) * scale_values
        )
        if hide_annotations:
            poi.name = ""
        poi_list.append(poi)
    return poi_list

def plz2_area_values(
        area_name: str,
        min_value: float = 0,
        max_value: float = 100,
        scale_values: float = 1
) -> pd.DataFrame:
    df = am.PLZ2_SHAPES[am.PLZ2_SHAPES["gebiet"] == area_name][["plz2"]].copy()
    df["value"] = df["plz2"].apply(lambda x: random.uniform(min_value, max_value) * scale_values)
    df.rename(columns={"plz2": "PLZ"}, inplace=True)
    df.set_index("PLZ", inplace=True)
    df = df.groupby(df.index)["value"].sum()  # Sum values for duplicate PLZ-2 areas
    return df

def plz3_area_values(
        area_name: str,
        min_value: float = 0,
        max_value: float = 100,
        scale_values: float = 1
) -> pd.DataFrame:
    df = am.PLZ3_SHAPES[am.PLZ3_SHAPES["gebiet"] == area_name][["plz3"]].copy()
    df["value"] = df["plz3"].apply(lambda x: random.uniform(min_value, max_value) * scale_values)
    df.rename(columns={"plz3": "PLZ"}, inplace=True)
    df.set_index("PLZ", inplace=True)
    df = df.groupby(df.index)["value"].sum()  # Sum values for duplicate PLZ-2 areas
    return df



def main():
    pass

if __name__ == "__main__":
    main()


import pandas as pd
import matplotlib.pyplot as plt
import area_viz.corporate_design as ci
import area_viz.area_maps as am
import area_viz.plot_data.generic as generic

def plz2_area(
        ax: plt.Axes,
        plz2_data: pd.DataFrame,
        area: str = "Deutschland",
        show_HQ: bool = True,
        show_sales_offices: bool = True,
        show_capital_cities: bool = True,
        caption: str = None
) -> plt.Axes:
    if ax == None:
        fig=plt.figure(figsize=(10, 5), dpi=200)
        ax=fig.add_subplot(1, 1, 1)
    plz2_gdf = am.PLZ2_SHAPES.copy()
    if area != "Deutschland":
        plz2_gdf = plz2_gdf[plz2_gdf["gebiet"].str.lower().str.contains(area.lower())]
    plz2_gdf["value"] = plz2_gdf["plz2"].map(plz2_data)
    plz2_gdf["value"] = plz2_gdf["value"].fillna(0)  # Optional: Fill NaN values with 0 for better visualization
    plz2_gdf.plot(column="value", ax=ax, legend=True, cmap="OrRd", edgecolor=ci.KOCO_COLORS.get("Grau"), linewidth=0.3)
    xlim = ax.get_xlim()
    ylim = ax.get_ylim()
    ax=am.AREA_SHAPES.boundary.plot(ax=ax, color=ci.KOCO_COLORS.get("HF_Blaugrau"), linewidth=1)
    am.AREA_SHAPES.apply(lambda x: ax.annotate(text=x["gebiet"], xy=x.geometry.centroid.coords[0], ha="center", fontweight="bold", fontsize=10, color=ci.KOCO_COLORS.get("Grau")), axis=1)
    ax.axes.set_axis_off()

    if show_HQ:
        generic.add_poi_to_map(ax, [am.HQ])
        
    if show_sales_offices:
        generic.add_poi_to_map(ax, am.SALES_OFFICES)
    
    if show_capital_cities:
        generic.add_poi_to_map(ax, am.CAPITAL_CITIES)
    if caption:
        plt.figtext(0.5, 0.01, caption, ha="center", fontsize=10)
    ax.set_xlim(xlim)
    ax.set_ylim(ylim)
    return ax

def plz3_area(
        ax: plt.Axes,
        plz3_data: pd.DataFrame,
        area: str = "Deutschland",
        show_HQ: bool = True,
        show_sales_offices: bool = True,
        show_capital_cities: bool = True,
        caption: str = None
) -> plt.Axes:
    if ax == None:
        fig=plt.figure(figsize=(10, 5), dpi=200)
        ax=fig.add_subplot(1, 1, 1)
    plz3_gdf = am.PLZ3_SHAPES.copy()
    if area != "Deutschland":
        plz3_gdf = plz3_gdf[plz3_gdf["gebiet"].str.lower().str.contains(area.lower())]
    plz3_gdf["value"] = plz3_gdf["plz3"].map(plz3_data)
    plz3_gdf["value"] = plz3_gdf["value"].fillna(0)  # Optional: Fill NaN values with 0 for better visualization
    plz3_gdf.plot(column="value", ax=ax, legend=True, cmap="Reds", edgecolor=ci.KOCO_COLORS.get("Grau"), linewidth=0.3)
    xlim = ax.get_xlim()
    ylim = ax.get_ylim()
    ax=am.AREA_SHAPES.boundary.plot(ax=ax, color=ci.KOCO_COLORS.get("HF_Blaugrau"), linewidth=1)
    am.AREA_SHAPES.apply(lambda x: ax.annotate(text=x["gebiet"], xy=x.geometry.centroid.coords[0], ha="center", fontweight="bold", fontsize=10, color=ci.KOCO_COLORS.get("Grau")), axis=1)

    if show_HQ:
        generic.add_poi_to_map(ax, [am.HQ])
        
    if show_sales_offices:
        generic.add_poi_to_map(ax, am.SALES_OFFICES)
    
    if show_capital_cities:
        generic.add_poi_to_map(ax, am.CAPITAL_CITIES)


    ax.axes.set_axis_off()
    if caption:
        plt.figtext(0.5, 0.01, caption, ha="center", fontsize=10)
    ax.set_xlim(xlim)
    ax.set_ylim(ylim)
    return ax




def main():
    pass    

if __name__ == "__main__":
    main()


import dataclasses as dc
import pandas as pd

@dc.dataclass
class POI:
    name: str
    coordinates: tuple[float, float]
    marker: str = 's'
    color: str = 'k'
    size: float = 10.0
    
def fetch_poi_from_poi_list(poi_list: list[POI], name: str) -> POI:
    for poi in poi_list:
        if poi.name == name:
            return poi
    return None 

def calc_scale_factor(df: pd.DataFrame, size_col: str, min_size: float = 10.0, max_size: float = 300.0) -> float:
    min_value = df[size_col].min()
    max_value = df[size_col].max()
    if max_value == min_value:
        return 1.0
    scale_factor = (max_size - min_size) / (max_value - min_value)
    return scale_factor

def plz_dataframe_to_poi_list(df: pd.DataFrame, plz2coord: dict[str, tuple[float, float]], data_col: str="DATA") -> list[POI]:
    poi_list = []
    scale_factor = calc_scale_factor(df, data_col)
    for _, row in df.iterrows():
        poi_item = fetch_poi_from_poi_list(plz2coord, row["PLZ"])
        if not poi_item:
            continue
        poi_item.name = row["NAME"][:3]  # Truncate name to first 3 characters
        poi_item.color = "blue"
        poi_item.marker = "o"
        poi_item.size = row[data_col] * scale_factor
        poi_list.append(poi_item)
    return poi_list


def main():
    pass    

if __name__ == "__main__":
    main()


import matplotlib.pyplot as plt
import area_viz.datamodel.poi as dm_poi

def add_poi_to_map(ax: plt.Axes, poi_list: list[dm_poi.POI], kwargs_scatter: dict = {}, kwargs_annotate: dict = {}) -> plt.Axes:
    for poi in poi_list:
        ax.scatter(poi.coordinates[0], poi.coordinates[1], color=poi.color, label=poi.name, marker=poi.marker, s=poi.size, **kwargs_scatter)
        ax.annotate(text=poi.name, xy=(poi.coordinates[0], poi.coordinates[1]), xytext=(3, 3), textcoords="offset points", fontsize=8, color=poi.color, **kwargs_annotate)
    return ax


def main():
    pass

if __name__ == "__main__":
    main()


import pandas as pd

def from_excel(file_path: str) -> pd.DataFrame:
    df = pd.read_excel(file_path, sheet_name="FIRMENLISTE", skiprows=3)
    return df

def main():
    pass

if __name__ == "__main__":
    main()


import matplotlib.pyplot as plt
import area_viz.corporate_design as ci
import area_viz.plot_data.generic as generic
import area_viz.area_maps as am

def basic_map(
        ax: plt.Axes|None, 
        show_plz2: bool = True, 
        show_area_shape: bool = True,
        show_HQ: bool = True,
        show_sales_offices: bool = True, 
        show_capital_cities: bool = True
    )->plt.Axes:
    if ax == None:
        fig = plt.figure(figsize=(15, 10), dpi=200)
        ax = fig.add_subplot(1, 1, 1)
    if show_plz2:
        ax=am.PLZ2_SHAPES.plot(ax=ax, legend=False, edgecolor=ci.KOCO_COLORS.get("Grau"), linewidth=0.3, color=am.PLZ2_SHAPES['color'], alpha=0.3)
        am.PLZ2_SHAPES.apply(lambda x: ax.annotate(text=x["plz2"], xy=x.geometry.centroid.coords[0], ha="center", fontsize=5, color=ci.KOCO_COLORS.get("Grau")), axis=1)

    if show_area_shape:
        ax=am.AREA_SHAPES.boundary.plot(ax=ax, color=ci.KOCO_COLORS.get("HF_Blaugrau"), linewidth=1)
        am.AREA_SHAPES.apply(lambda x: ax.annotate(text=x["gebiet"], xy=x.geometry.centroid.coords[0], ha="center", fontweight="bold", fontsize=10, color=ci.KOCO_COLORS.get("Grau")), axis=1)
    ax.axes.set_axis_off()
    if ax is None:
        return None

    if show_HQ:
        generic.add_poi_to_map(ax, [am.HQ])
        
    if show_sales_offices:
        generic.add_poi_to_map(ax, am.SALES_OFFICES)
    
    if show_capital_cities:
        generic.add_poi_to_map(ax, am.CAPITAL_CITIES)
    return ax

def basic_map_area(
        ax: plt.Axes|None,
        area_name: str, 
        show_plz2: bool = True, 
        show_area_shape: bool = True,
        show_HQ: bool = True,
        show_sales_offices: bool = True, 
        show_capital_cities: bool = True
    )->plt.Axes:
    if ax == None:
        fig = plt.figure(figsize=(15, 10), dpi=200)
        ax = fig.add_subplot(1, 1, 1)
    if show_plz2:
        plz2_area = am.PLZ2_SHAPES.where(am.PLZ2_SHAPES["gebiet"] == area_name).dropna(subset=["geometry"])
        ax=plz2_area.plot(ax=ax, legend=False, figsize=(10, 10), edgecolor=ci.KOCO_COLORS.get("Grau"), linewidth=0.3, color=plz2_area['color'], alpha=0.3)
        plz2_area.apply(lambda x: ax.annotate(text=x["plz2"], xy=x.geometry.centroid.coords[0], ha="center", fontsize=5, color=ci.KOCO_COLORS.get("Grau")), axis=1)

    if show_area_shape:
        area_shape = am.AREA_SHAPES.where(am.AREA_SHAPES["gebiet"] == area_name).dropna(subset=["geometry"])
        ax=area_shape.boundary.plot(ax=ax, color=ci.KOCO_COLORS.get("HF_Blaugrau"), linewidth=1)
        area_shape.apply(lambda x: ax.annotate(text=x["gebiet"], xy=x.geometry.centroid.coords[0], ha="center", fontweight="bold", fontsize=10, color=ci.KOCO_COLORS.get("Grau")), axis=1)
    ax.axes.set_axis_off()
    xlim = ax.get_xlim()
    ylim = ax.get_ylim()
    if ax is None:
        return None

    if show_HQ:

        generic.add_poi_to_map(ax, [am.HQ])
        
    if show_sales_offices:
        generic.add_poi_to_map(ax, am.SALES_OFFICES)
    
    if show_capital_cities:
        generic.add_poi_to_map(ax, am.CAPITAL_CITIES)
    ax.set_xlim(xlim)
    ax.set_ylim(ylim)
    return ax

def germany_sales_areas() -> plt.Axes:
    fig = plt.figure(figsize=(10, 15))
    ax = fig.add_subplot(1, 1, 1)

    ax=basic_map(
        ax=ax, 
        show_plz2=True, 
        show_area_shape=True,
        show_HQ=True, 
        show_sales_offices=True, 
        show_capital_cities=True
    )
    return ax


def germany_sales_area(area_name: str) -> plt.Axes:
    fig = plt.figure(figsize=(10, 15))
    ax = fig.add_subplot(1, 1, 1)

    ax=basic_map_area(
        ax=ax, 
        area_name=area_name, 
        show_plz2=True, 
        show_area_shape=True, 
        show_HQ=True, 
        show_sales_offices=True, 
        show_capital_cities=True
    )
    return ax



def main():
    pass

if __name__ == "__main__":
    main()


import geopandas as gpd
import area_viz.corporate_design as ci
import os

def map_plz_areas(plz2: str, area_mapping: dict) -> str:
    for area, prefixes in area_mapping.items():
        if plz2 in prefixes:
            return area
    return "Unknown"    

def create_shape_file(input_file: str, output_file: str, area_mapping: dict)->None:
    plz_data = gpd.read_file(input_file)
    plz_data_2digits = plz_data.copy()
    plz_data_2digits["plz2"] = plz_data_2digits["plz"].str[:2]
    plz2 = plz_data_2digits[["plz2", "geometry"]].dissolve(by="plz2", as_index=False)
    plz2['gebiet'] = plz2['plz2'].apply(lambda x: map_plz_areas(x, area_mapping))
    plz2['color'] = plz2['gebiet'].map(ci.AREA_MAPPING_COLOR_MAPPING)
    # print(plz2[['plz2', 'gebiet', 'color']].head())
    plz2.to_file(output_file)

def load_shape_file(input_file: str, output_file: str, area_mapping: dict, enforce_new_creation: bool = False) -> gpd.GeoDataFrame:
    if enforce_new_creation or not os.path.exists(output_file):
        create_shape_file(input_file, output_file, area_mapping)
    plz2 = gpd.read_file(output_file)
    return plz2


def main():
    pass


if __name__ == "__main__":
    main()


import geopandas as gpd
import area_viz.datamodel.poi as poi
import area_viz.corporate_design as ci
import dataclasses as dc
import json
import os

def create_coords_file(output_file: str, plz_shape_file: str)->None:
    print("Creating PLZ coordinates file...")
    plz_data = gpd.read_file(plz_shape_file)
    plz_data["coords"] = plz_data.geometry.centroid.apply(lambda point: (point.x, point.y))
    plz_coords = [poi.POI(name=row["plz"], coordinates=row["coords"], color=ci.KOCO_COLORS.get("Schwarzgrau")) for _, row in plz_data.iterrows()]
    with open(output_file, "w") as f:
        json.dump([dc.asdict(p) for p in plz_coords], f)
    

def load_coords_file(output_file: str, plz_shape_file: str, enforce_new_creation: bool = False) -> list[poi.POI]:
    if enforce_new_creation or not os.path.exists(output_file):
        create_coords_file(output_file, plz_shape_file)
    with open(output_file, "r") as f:
        plz_coords = json.load(f)
    return [poi.POI(**p) for p in plz_coords]

def main():
    pass


if __name__ == "__main__":
    main()


import geopandas as gpd
import os

def create_shape_file(output_file_path: str, plz2_file: str) -> None:
    plz2 = gpd.read_file(plz2_file)
    gebiete = plz2.copy()
    gebiete = gebiete[['gebiet','geometry','color']].dissolve(by='gebiet', as_index=False)
    # print(gebiete[['gebiet']].head())
    gebiete.to_file(output_file_path)

def load_shape_file(file_path: str, plz2_file: str, enforce_new_creation: bool = False) -> gpd.GeoDataFrame:
    if enforce_new_creation or not os.path.exists(file_path):
        create_shape_file(file_path, plz2_file)
    gebiete = gpd.read_file(file_path)
    return gebiete

def main():
    pass

if __name__ == "__main__":
    main()


import geopandas as gpd
import area_viz.corporate_design as ci
import os

def map_plz_areas(plz3: str, area_mapping: dict) -> str:
    for area, prefixes in area_mapping.items():
        if plz3 in prefixes:
            return area
    return "Unknown"    

def create_shape_file(input_file: str, output_file: str, area_mapping: dict)->None:
    plz_data = gpd.read_file(input_file)
    plz_data_3digits = plz_data.copy()
    plz_data_3digits["plz2"] = plz_data_3digits["plz"].str[:2]
    plz_data_3digits["plz3"] = plz_data_3digits["plz"].str[:3]
    plz3 = plz_data_3digits[["plz2","plz3", "geometry"]].dissolve(by="plz3", as_index=False)
    plz3['gebiet'] = plz3['plz2'].apply(lambda x: map_plz_areas(x, area_mapping))
    plz3['color'] = plz3['gebiet'].map(ci.AREA_MAPPING_COLOR_MAPPING)
    plz3.to_file(output_file)

def load_shape_file(input_file: str, output_file: str, area_mapping: dict, enforce_new_creation: bool = False) -> gpd.GeoDataFrame:
    if enforce_new_creation or not os.path.exists(output_file):
        create_shape_file(input_file, output_file, area_mapping)
    plz3 = gpd.read_file(output_file)
    return plz3


def main():
    pass


if __name__ == "__main__":
    main()


import area_viz.area_maps.cities as cities
import area_viz.area_maps.plz_coords as plz_coords
import area_viz.area_maps.plz2_shape as plz2_shape
import area_viz.area_maps.plz3_shape as plz3_shape
import area_viz.area_maps.area_shape as area_shape
import area_viz.datamodel.poi as poi
import area_viz.corporate_design as ci

import dotenv
import os

dotenv.load_dotenv()  # Load environment variables from .env file

LARGE_DATA_FOLDER = os.getenv('AV_LARGE_DATA_FOLDER', 'large_data')

ENFORCE_NEW_CREATION = os.getenv('AV_ENFORCE_NEW_CREATION', 'False').lower() in ('true', '1', 't')

PLZ_SHAPE_FILE = os.path.join(LARGE_DATA_FOLDER, "PLZ_Gebiete/OSM_PLZ.shp")
PLZ_COORDS_FILE = os.path.join(LARGE_DATA_FOLDER, "PLZ_Gebiete/PLZ_Coords.json")
PLZ_2DIGITS_SHAPE_FILE = os.path.join(LARGE_DATA_FOLDER, "PLZ_Gebiete/OSM_PLZ_2digits.shp")
PLZ_3DIGITS_SHAPE_FILE = os.path.join(LARGE_DATA_FOLDER, "PLZ_Gebiete/OSM_PLZ_3digits.shp")
GEBIETE_SHAPE_FILE = os.path.join(LARGE_DATA_FOLDER, "PLZ_Gebiete/OSM_Gebiete.shp")
CAPITAL_CITIES_URL = os.path.join(LARGE_DATA_FOLDER, "city_data/Hauptstädte der deutschen Bundesländer (PLZ, Hauptstadt).csv")


AREA_MAPPING = {
    "Ost": [
        "00", "01", "02", "03", "04", "05", "06", "07", "08", "09", 
        "10", "11", "12", "13", "14", "15", "16", "17", "18", "19",
        "20", "21", "22", "23", "24", "25", "26", "27", "28", "29",
        "38", "39"],
    "West": ["30", "31", "32", "33", "34", "35", "36", "37",
             "40", "41", "42", "43", "44", "45", "46", "47", "48", "49",
             "50", "51", "52", "53", "54", "55", "56", "57", "58", "59",
             "60", "61", "62", "63", "65", "97"],
    "BW": ["64", "66", "67", "68", "69",
           "70", "71", "72", "73", "74", "75", "76", "77", "78", "79",
           "88", "89"],
    "Bayern": ["80", "81", "82", "83", "84", "85", "86", "87",
               "90", "91", "92", "93", "94", "95", "96", "98", "99"],
}


HQ_PLZ = "78083"
SALES_OFFICES_PLZ = {'BW':"71032", 'West':"65934", 'Bayern':"92224", 'Bayern_2':"90491", 'Ost':"01458"}

PLZ_COORDS = plz_coords.load_coords_file(output_file=PLZ_COORDS_FILE, plz_shape_file=PLZ_SHAPE_FILE, enforce_new_creation=ENFORCE_NEW_CREATION)
CAPITAL_CITIES = cities.load_capital_cities(capital_cities_url=CAPITAL_CITIES_URL)

HQ = poi.fetch_poi_from_poi_list(PLZ_COORDS, HQ_PLZ)
HQ.name = "HQ"
HQ.color = ci.KOCO_COLORS.get("HF_Orange")
HQ.marker = "x"

SALES_OFFICES = []
for office_plz in SALES_OFFICES_PLZ:
    office_coords = poi.fetch_poi_from_poi_list(PLZ_COORDS, SALES_OFFICES_PLZ.get(office_plz))
    if office_coords:
        office_coords.name = f"Büro {office_plz}"
        office_coords.color = ci.KOCO_COLORS.get("HF_Lila")
        office_coords.marker = "D"
        SALES_OFFICES.append(office_coords)

PLZ2_SHAPES = plz2_shape.load_shape_file(input_file=PLZ_SHAPE_FILE, output_file=PLZ_2DIGITS_SHAPE_FILE, area_mapping=AREA_MAPPING, enforce_new_creation=ENFORCE_NEW_CREATION)
PLZ3_SHAPES = plz3_shape.load_shape_file(input_file=PLZ_SHAPE_FILE, output_file=PLZ_3DIGITS_SHAPE_FILE, area_mapping=AREA_MAPPING, enforce_new_creation=ENFORCE_NEW_CREATION)   
AREA_SHAPES = area_shape.load_shape_file(file_path=GEBIETE_SHAPE_FILE, plz2_file=PLZ_2DIGITS_SHAPE_FILE, enforce_new_creation=ENFORCE_NEW_CREATION)
